##  Code Configurations and Execution Log
You can view all custom code configurations used in calculations in the Managed Code section of the administration area. Here, you can review managed code execution logs for script runs to help troubleshoot script-level issues. These logs do not show an end-to-end view of calculation execution or outcomes. For more information, see [Managed Code](https://help.sap.com/docs/leanix/ea/managed-code?locale=en-US&state=PRODUCTION&version=CLOUD "View and manage all custom code configurations used in automations, calculations, and webhooks across your workspace. Monitor execution logs to track history, troubleshoot issues, and ensure your code runs as expected.").
